@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,36 +29,37 @@ HIGHEST_NOTENAME="g''''''"
 from const import FIRST, LAST, ALL
 
 import parser, soundcard
-import string, os, types
+import string, types
 from musicalpitch import MusicalPitch
 from intervall import Intervall
+from utils import notename_to_int, int_to_notename
 
-def music_to_tracklist(music):
+def music_to_tracklist(music, velocity):
     """
     return a list of tracks, where track[0] use only channel 0,
     track[1] only use channel 1 etc.
     """
     score = parser.parse_to_score_object(music)
-    tracks = score.get_midi_events()
+    tracks = score.get_midi_events(velocity)
     score.help__del__() # python need a little help to avoid memory leaks
     return tracks
 
-def music_to_track(music, start=None, end=None):
+def music_to_track(music, velocity, start=None, end=None):
     score = parser.parse_to_score_object(music)
-    tracklist = score.get_midi_events(start, end)
+    tracklist = score.get_midi_events(velocity, start, end)
     score.help__del__() # python need a little help to avoid memory leaks
     track = tracklist[0]
     for x in range(1, len(tracklist)):
         track.merge_with(tracklist[x])
     return track
 
-def play_music(music, tempo, patch):
+def play_music(music, tempo, patch, velocity):
     if type(tempo) == type(0):
         bpm = tempo
         nl = 4
     else:
         bpm, nl = tempo
-    track = music_to_track(music)
+    track = music_to_track(music, velocity)
     track.prepend_bpm(bpm, nl)
     for c in range(soundcard.synth.NUM_CHANNELS):
         track.prepend_patch(c, patch)
@@ -68,15 +69,6 @@ def play_music(music, tempo, patch):
 # midi functions #
 ##################
 
-def int_to_notename(i):
-    p = MusicalPitch(0, 0, 0)
-    p.set_from_midiint(i)
-    return p.str()
-
-def notename_to_int(n):
-    p = MusicalPitch(n)
-    return p.semitone_pitch()
-
 def transpose_notename(n, t):
     assert type(n) == types.StringType
     assert type(t) == types.IntType
