@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,18 +19,19 @@ from soundcard.rat import Rat
 import const
 import gtk
 import utils
+import operator
 
 fetadir = "feta"
 class dim20:
     linespacing = 8
-    stemlen = linespacing * 3
+    stemlen = linespacing * 3.5
     xshift = 10
-    accidental_width = 10
-    col_width = 30
+    col_width = 20
     first_staff_ypos = 50
     staff_spacing = 70
     ledger_left = -4
     ledger_right = 14
+    accidental_widths = { -2: 12, -1: 7, 0: 5, 1: 8, 2: 8}
     clef_yoffset = {'violin': linespacing-38,
                     'treble': linespacing-38,#treble == violin
                     'subbass': -8-2*linespacing,
@@ -61,6 +62,7 @@ class Engraver:
         raise "Abstract base class"
     def get_width(self):
         # this value will be used for engravers that don't override this method.
+        # FIXME
         return 20
     def __str__(self):
         return '(Engraver)'
@@ -86,7 +88,7 @@ class ClefEngraver(Engraver):
               'mezzosoprano': 'C',
               'soprano': 'C',
               'french': 'G'}[self.m_cleftype]
-        xpm = gtk.create_pixmap_from_xpm(w, None, 
+        xpm = gtk.create_pixmap_from_xpm(w, None,
               fetadir+'/feta%i-clefs-%s.xpm' % (self.m_fontsize, fn))[0]
         gtk.draw_pixmap(pixmap, gc, xpm, 0, 0,
                     self.m_xpos,
@@ -101,11 +103,10 @@ class TimeSignatureEngraver(Engraver):
     def set_xpos(self, dict):
         self.m_xpos = dict[self.m_timepos].m_timesignature
     def engrave(self, w, pixmap, gc, staff_yoffset):
-        dim = dimentions[self.m_fontsize]
         x = 0
         for idx in range(len(str(self.m_timesig.m_num))):
             n = str(self.m_timesig.m_num)[idx]
-            xpm = gtk.create_pixmap_from_xpm(w, None, 
+            xpm = gtk.create_pixmap_from_xpm(w, None,
                 fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))[0]
             gtk.draw_pixmap(pixmap, gc, xpm, 0, 0,
                     self.m_xpos+x, staff_yoffset-12, -1, -1)
@@ -113,7 +114,7 @@ class TimeSignatureEngraver(Engraver):
         x = 0
         for idx in range(len(str(self.m_timesig.m_den))):
             n = str(self.m_timesig.m_den)[idx]
-            xpm = gtk.create_pixmap_from_xpm(w, None, 
+            xpm = gtk.create_pixmap_from_xpm(w, None,
                 fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))[0]
             gtk.draw_pixmap(pixmap, gc, xpm, 0, 0,
                     self.m_xpos+x, staff_yoffset+3, -1, -1)
@@ -134,19 +135,16 @@ class TieEngraver(Engraver):
     def set_xpos(self, dict):
         self.m_xpos1 = dict[self.m_pos1].m_music
         self.m_xpos2 = dict[self.m_pos2].m_music
-        #ugh the musicdisplayer want every engraver to have a m_xpos to
+        #FIXME the musicdisplayer want every engraver to have a m_xpos to
         # know how wide the whole music is. Fixthis
         self.m_xpos = self.m_xpos2
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        A = self.m_xpos1+dim.xshift*1.5
-        C = self.m_xpos2-dim.xshift/2
-        M = A + (C-A)/2
         self.m_xpos1 = self.m_xpos1 + 3 + (self.m_shift1 + 1) * dim.xshift
         self.m_xpos2 = self.m_xpos2 - 3 + self.m_shift2 * dim.xshift
         w = self.m_xpos2 - self.m_xpos1
         h = 8
-        gtk.draw_arc(pixmap, gc, gtk.FALSE, 
+        gtk.draw_arc(pixmap, gc, gtk.FALSE,
                      self.m_xpos1, staff_yoffset + dim.linespacing*(self.m_ylinepos-1)/2 + 3,
                      w, h, 64 * 180, 64*180)
 
@@ -155,29 +153,36 @@ class AccidentalsEngraver(Engraver):
     def __init__(self, timepos, fontsize, accs):
         Engraver.__init__(self, timepos, fontsize)
         self.m_accs = accs
-    def set_xpos(self, dict):
-        self.m_xpos = dict[self.m_timepos].m_accidentals
+        def f(v, w=dimentions[fontsize].accidental_widths):
+            x = 0
+            for a in v:
+                x = x + w[a]
+            return x
+        self.m_usize = reduce(operator.__add__, map(f, accs.values())) + len(accs)
+    def set_xpos(self, dict, tpd):
+        self.m_xpos = dict[self.m_timepos].m_accidentals + tpd[self.m_timepos].m_accidentals - self.get_width()
     def get_width(self):
-        return len(self.m_accs.keys())*10
+        return self.m_usize
     def engrave(self, w, pixmap, gc, staff_yoffset):
         x = 0
         for y in self.m_accs.keys():
-            y_offset = {const.ACCIDENTAL__2: -7,
-                    const.ACCIDENTAL__1: -7,
-                    const.ACCIDENTAL_0: -5,
-                    const.ACCIDENTAL_1: -6,
-                    const.ACCIDENTAL_2: -2}
-            xpm = gtk.create_pixmap_from_xpm(w, None, 
-                fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize,
-                          self.m_accs[y]))[0]
-            gtk.draw_pixmap(pixmap, gc,
-                    xpm, 0, 0,
-                    self.m_xpos + x, 
-                    y_offset[self.m_accs[y]] + staff_yoffset 
-                     + dimentions[self.m_fontsize].linespacing*y/2
-                     + y_offset[self.m_accs[y]],
-                    -1, -1)
-            x = x + 10
+            for acc in self.m_accs[y]:
+                y_offset = {const.ACCIDENTAL__2: -7,
+                            const.ACCIDENTAL__1: -7,
+                            const.ACCIDENTAL_0: -5,
+                            const.ACCIDENTAL_1: -6,
+                            const.ACCIDENTAL_2: -2}
+                xpm = gtk.create_pixmap_from_xpm(w, None,
+                    fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize,
+                              acc))[0]
+                gtk.draw_pixmap(pixmap, gc,
+                        xpm, 0, 0,
+                        self.m_xpos + x,
+                        y_offset[acc] + staff_yoffset
+                         + dimentions[self.m_fontsize].linespacing*y/2
+                         + y_offset[acc],
+                        -1, -1)
+                x = x + dimentions[self.m_fontsize].accidental_widths[acc] + 1
 
 
 class KeySignatureEngraver(Engraver):
@@ -189,43 +194,37 @@ class KeySignatureEngraver(Engraver):
     def set_xpos(self, dict):
         self.m_xpos = dict[self.m_timepos].m_keysignature
     def get_width(self):
-        #ugh this value depends on the fontsize, and on what kind of
+        #FIXME this value depends on the fontsize, and on what kind of
         #accidental we are drawing. A sharp is wider that a flat.
         return len(self.m_accidentals) * 10 + 10
     def engrave(self, w, pixmap, gc, staff_yoffset):
         x = 0
         for acc in self.m_accidentals:
-            if self.m_clef == 'bass':
-                ypos = {'ees': -1, 'des': 0, 'ces': 1,
-                    'bes': 2, 'aes': 3, 'ges': 4, 'fes': 5,
-                    'gis': -3, 'fis': -2, 'eis': -1, 'dis': 0,
-                    'cis': 1, 'bis': 2, 'ais': 3}[acc]
-            elif self.m_clef == 'violin' or self.m_clef == 'treble':
-                ypos = {'gis': -5, 'fis': -4, 'eis': -3, 'dis': -2, 'cis': -1,
-                    'bis': 0, 'ais': 1, 'ees': -3, 'des': -2, 'ces': -1,
-                    'bes': 0, 'aes': 1, 'ges': 2, 'fes': 3}[acc]
-            else:
-                raise "unknown clef:", self.m_clef
-            if acc in ['ces', 'des', 'ees', 'fes', 'ges', 'aes', 'bes']:
+            ypos = utils.an_to_ylinepos(acc, self.m_clef)
+            if acc[-4:] == 'eses':
+                type = -2
+            elif acc[-2:] == 'es':
                 type = -1
+            elif acc[-4:] == 'isis':
+                type = 2
             else:
                 type = 1
-            #ugh duplicated elsewhere
+            #FIXME duplicated elsewhere
             y_offset = {const.ACCIDENTAL__2: -7,
                     const.ACCIDENTAL__1: -7,
                     const.ACCIDENTAL_0: -5,
                     const.ACCIDENTAL_1: -6,
                     const.ACCIDENTAL_2: -2}
-            xpm = gtk.create_pixmap_from_xpm(w, None, 
+            xpm = gtk.create_pixmap_from_xpm(w, None,
                 fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, type))[0]
             gtk.draw_pixmap(pixmap, gc,
                     xpm, 0, 0,
-                    self.m_xpos + x, 
-                    y_offset[type] + staff_yoffset 
+                    self.m_xpos + x,
+                    y_offset[type] + staff_yoffset
                      + dimentions[self.m_fontsize].linespacing*ypos/2
                      + y_offset[type],
                     -1, -1)
-            #ughsee .get_width
+            #FIXME see FIXME msg in .get_width
             x = x + 10
 
 
@@ -235,7 +234,8 @@ class NoteheadEngraver(Engraver):
         m_ypos == 0 is the middle line on the staff.
         Negative value is up, positive is down.
         The value counts notesteps, not pixels!
-        ugh, right now it also draws dots, but they should be an own class.
+        FIXME, right now it also draws dots, but they should be an own class
+        because the dots has to be handled special with noteheads are xshifted.
         """
         Engraver.__init__(self, timepos, fontsize)
         self.m_head = head
@@ -248,18 +248,18 @@ class NoteheadEngraver(Engraver):
         self.m_xpos = dict[self.m_timepos].m_music
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        xpm = gtk.create_pixmap_from_xpm(w, None, 
+        xpm = gtk.create_pixmap_from_xpm(w, None,
                 fetadir+'/feta%i-noteheads-%i.xpm' % (self.m_fontsize, self.m_head))[0]
         gtk.draw_pixmap(pixmap, gc,
                     xpm, 0, 0,
-                    self.m_xpos + self.m_shift * dim.xshift, 
+                    self.m_xpos + self.m_shift * dim.xshift,
                     staff_yoffset + dim.linespacing*self.m_ypos/2 - 4,
                     -1, -1)
         dot = gtk.create_pixmap_from_xpm(w, None, fetadir+'/feta20-dots-dot.xpm')[0]
         for n in range(self.m_numdots):
             gtk.draw_pixmap(pixmap, gc,
                         dot, 0, 0,
-                        self.m_xpos+dim.xshift*(self.m_shift+1.5+n/2.0), 
+                        self.m_xpos+dim.xshift*(self.m_shift+1.5+n/2.0),
                         -3 + staff_yoffset + dim.linespacing*self.m_ypos/2,
                         -1, -1)
     def get_pixmap_id(self):
@@ -280,14 +280,57 @@ class BarlineEngraver(Engraver):
         return 8
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        gtk.draw_line(pixmap, gc, 
-                self.m_xpos, staff_yoffset - dim.linespacing*2, 
+        gtk.draw_line(pixmap, gc,
+                self.m_xpos, staff_yoffset - dim.linespacing*2,
                 self.m_xpos, staff_yoffset + dim.linespacing*2)
 
+class TupletEngraver(Engraver):
+    def __init__(self, fontsize, n):
+        Engraver.__init__(self, None, fontsize)
+        self.m_stems = []
+        self.m_den, self.m_direction = n
+    def set_xpos(self, dict):
+        pass
+    def add_stem(self, stem):
+        self.m_stems.append(stem)
+    def do_layout(self):
+        dim = dimentions[self.m_fontsize]
+        top = []
+        bottom = []
+        for s in self.m_stems:
+            if s.m_mgroup.m_stemdir == const.UP:
+                top.append(min(s.m_yposes)-7)
+                bottom.append(max(s.m_yposes)+1)
+            else:
+                top.append(min(s.m_yposes))
+                bottom.append(max(s.m_yposes)+5)
+        self.m_t = min(top) - 2
+        self.m_b = max(bottom) + 2
+        self.m_xpos1 = self.m_stems[0].m_xpos
+        self.m_xpos2 = self.m_stems[-1].m_xpos + dim.xshift
+    def engrave(self, w, pixmap, gc, staff_yoffset):
+        dim = dimentions[self.m_fontsize]
+        m = self.m_xpos1 + (self.m_xpos2 - self.m_xpos1)/2
+        x1 = m - 6
+        x2 = m + 6
+        if self.m_direction == const.UP or self.m_direction == const.BOTH:
+            y = min(staff_yoffset - dim.linespacing * 3,
+                   staff_yoffset + self.m_t * dim.linespacing / 2)
+            d = 1
+        else: # == const.DOWN
+            y = max(staff_yoffset + dim.linespacing * 5,
+                    staff_yoffset + self.m_b * dim.linespacing /2)
+            d = -1
+        gtk.draw_line(pixmap, gc, self.m_xpos1, y, x1, y)
+        gtk.draw_line(pixmap, gc, x2, y, self.m_xpos2, y)
+        gtk.draw_line(pixmap, gc, self.m_xpos1, y, self.m_xpos1, y+5*d)
+        gtk.draw_line(pixmap, gc, self.m_xpos2, y, self.m_xpos2, y+5*d)
+        font = gtk.load_font("-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*")
+        gtk.draw_string(pixmap, font, gc, m-3, y + 3, str(self.m_den))
+
 class BeamEngraver(Engraver):
     def __init__(self, fontsize):
         Engraver.__init__(self, None, fontsize)
-        dim = dimentions[self.m_fontsize]
         self.m_stems = []
     def add_stem(self, stem_engraver):
         self.m_stems.append(stem_engraver)
@@ -336,15 +379,12 @@ class BeamEngraver(Engraver):
         for e in self.m_stems:
             e.m_mgroup.m_stemdir = stemdir
     def engrave(self, w, pixmap, gc, staff_yoffset):
-        """I can guarantee you all that this function has bugs...
-        Just let me know of them.
-        """
         dim = dimentions[self.m_fontsize]
         if self.m_stemdir == const.UP:
            d = 1
         else:
            d = -1
-        x1 = self.m_stems[0].m_xpos 
+        x1 = self.m_stems[0].m_xpos
         x2 = self.m_stems[-1].m_xpos
         if self.m_stems[0].m_beamed_stem_top % 2 == 1:
             for x in range(len(self.m_stems)):
@@ -412,15 +452,15 @@ class StemEngraver(Engraver):
         self.m_stemlen = dimentions[self.m_fontsize].stemlen
     def set_xpos(self, dict):
         self.m_xpos = dict[self.m_timepos].m_music
-    def xshift_stem(self):
-        if self.m_mgroup.m_stemdir == const.UP:
+    def calc_xpos(self):
+        if self.m_mgroup.m_stempos == 1 or self.m_mgroup.m_stemdir == const.UP:
             self.m_xpos = self.m_xpos + dimentions[self.m_fontsize].xshift
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
         # draw flags
         if  not self.m_is_beamed and self.m_mgroup.m_duration.m_nh > 4:
             if self.m_mgroup.m_stemdir == const.UP:
-                xpm = gtk.create_pixmap_from_xpm(w, None, 
+                xpm = gtk.create_pixmap_from_xpm(w, None,
                     fetadir+'/feta%i-flags-%s.xpm' % (self.m_fontsize, self.get_flag(const.UP)))[0]
                 gtk.draw_pixmap(pixmap, gc,
                             xpm, 0, 0,
@@ -428,7 +468,7 @@ class StemEngraver(Engraver):
                             staff_yoffset - self.m_stemlen + self.m_yposes[0] * dim.linespacing/2,
                             -1, -1)
             else:
-                xpm = gtk.create_pixmap_from_xpm(w, None, 
+                xpm = gtk.create_pixmap_from_xpm(w, None,
                     fetadir+'/feta%i-flags-%s.xpm' % (self.m_fontsize, self.get_flag(const.DOWN)))[0]
                 gtk.draw_pixmap(pixmap, gc,
                             xpm, 0, 0,
@@ -448,10 +488,10 @@ class StemEngraver(Engraver):
             else:
                 yroot = self.m_yposes[0] - 6
             ytop = self.m_yposes[-1]
-        gtk.draw_line(pixmap, gc, 
+        gtk.draw_line(pixmap, gc,
                      self.m_xpos,
                      ytop * dim.linespacing/2 + staff_yoffset,
-                     self.m_xpos, 
+                     self.m_xpos,
                      yroot * dim.linespacing/2 + staff_yoffset)
     def get_flag(self, dir):
         assert self.m_mgroup.m_duration.m_nh > 4
@@ -464,6 +504,8 @@ class StemEngraver(Engraver):
                 64: {const.UP: const.FLAG_64UP,
                                const.DOWN: const.FLAG_64DOWN}} \
                               [self.m_mgroup.m_duration.m_nh][dir]
+    def __str__(self):
+        return "(StemEngraver)"
 
 
 class LedgerLineEngraver(Engraver):
@@ -505,7 +547,7 @@ class RestEngraver(Engraver):
     def set_xpos(self, dict):
         self.m_xpos = dict[self.m_timepos].m_music
     def get_width(self):
-        #ugh write me!
+        #FIXME write me!
         return 20
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
