@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import types, random, string
-import intervall
+import types, random
 
 class InvalidNotenameException:
     def __init__(self, n):
@@ -26,7 +25,7 @@ class InvalidNotenameException:
 
 class MusicalPitch:
     LOWEST_STEPS = -28
-    HIGHEST_STEPS = 46
+    HIGHEST_STEPS = 47
     def __init__(self, n=None, a=None, o=None, null_value=0):
         """Will accept five types of arguments:
         0.   n is None, set to "c"
@@ -130,7 +129,7 @@ class MusicalPitch:
             v = self.semitone_pitch()
             assert 0 <= v + i < 128
             return MusicalPitch(v+i)
-        elif isinstance(i, intervall.Intervall): 
+        elif i.__class__.__name__ == 'Intervall':#isinstance(i, intervall.Intervall):
             r = MusicalPitch(self)
             _p = r.semitone_pitch()
             r.m_notename_i = r.m_notename_i + i.m_intervall * i.m_dir
@@ -167,10 +166,10 @@ class MusicalPitch:
         return MusicalPitch(v-i)
     def __int__(self):
         return self.semitone_pitch()
-    def __cmp__(A, B):
-        if (A is None or B is None):
+    def __cmp__(self, B):
+        if (self is None or self is None):
             return -1
-        diff = A - B
+        diff = self - B
         if diff < 0:
             return -1
         elif diff > 0:
