@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,15 +24,16 @@ import musicalpitch
 import gnome.ui
 
 class MusicDisplayer(gtk.GtkScrolledWindow):
-    def __init__(self):
+    def __init__(self, callback):
         gtk.GtkScrolledWindow.__init__(self)
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_NEVER)
+        self.m_callback = callback
         self.m_engravers = [[],]
         self.m_fontsize = 20
         self.m_clickables = []
         self.g_d = gtk.GtkDrawingArea()
         self.g_d.show()
-        
+
         self.add_with_viewport(self.g_d)
         self.g_d.connect("expose_event", self.on_expose_event)
         self.g_d.add_events(gtk.GDK.EXPOSURE_MASK | gtk.GDK.BUTTON_PRESS_MASK)
@@ -47,8 +48,8 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
         dim = engravers.dimentions[20]
         self.set_usize(-1, numstaff*dim.staff_spacing+dim.first_staff_ypos)
     def display_range(self, music, fontsize, start, end):
-        #ugh handle exceptions
-        #ugh this function only handles music where start == Rat(0, 1) correctly
+        #FIXME handle exceptions
+        #FIXME this function only handles music where start == Rat(0, 1) correctly
         if start != soundcard.rat.Rat(0, 1):
             print "warning: musicdisplayer.display_range: start != Rat(0, 1)"
         score = parser.parse_to_score_object(music)
@@ -88,7 +89,8 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
         for r in self.m_clickables:
             if r['x'] < event.x < r['x'] + r['w'] \
                and r['y'] < event.y < r['y'] + r['h']:
-                soundcard.play_note(0, 4, 0, r['midi_int'])
+                self.m_callback(r['midi_int'])
+                #soundcard.play_note(0, 4, 0, r['midi_int'])
     def on_expose_event(self, darea, event):
         self.white_gc = self.g_d.get_style().white_gc
         self.black_gc = self.g_d.get_style().black_gc
@@ -104,7 +106,6 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
             gtk.draw_rectangle(pixmap, self.white_gc, gtk.TRUE, 0, 0,
                                self.m_width, self.m_height)
             staff_centrum = dim.first_staff_ypos
-            first_note_xpos = -1
             self.m_clickables = []
             for staff in self.m_engravers:
                 for e in staff:
