@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,22 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from track import Track
-import types, os
-from exceptions import SoundInitException
+import types
+from soundcardexceptions import SoundInitException
 synth = None
 
+def initialise_winsynth(verbose_init=0):
+    import winsynth
+    global synth
+    synth = winsynth.WinSynth(verbose_init)
+
+
 def initialise_external_midiplayer(cmdline, verbose_init=0):
     global synth
     import midifilesynth
     synth = midifilesynth.MidiFileSynth(cmdline, verbose_init)
 
+
 def initialise_devicefile(devicefile, devicenum=0, card_info=None,
                           verbose_init=0):
     global synth
@@ -39,7 +46,7 @@ def initialise_devicefile(devicefile, devicenum=0, card_info=None,
         synth = oss_sequencer.OSSSequencerSynth(devicefile, devicenum, 
                                                 card_info, verbose_init)
 
-def initialise_using_fake_synth(verbose_init):
+def initialise_using_fake_synth(verbose_init=None):
     global synth
     import fakesynth
     synth = fakesynth.Synth(verbose_init)
