@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys, os, types, tempfile, string, signal
-import mfutils, rat
+import mfutils
+
+def ms_win_kill(pid):
+    import win32api
+    handle = win32api.OpenProcess(1, 0, pid)
+    return (0 != win32api.TerminateProcess(handle, 0))
 
 class MidiFileSynth:
     NUM_CHANNELS = 16
@@ -54,10 +59,6 @@ class MidiFileSynth:
         # spawnl(os.P_DETACH, 'c:\\python20\\python', 'python', 'script.py')
         # #P_DETACH'ed can be killed
     def _play_track_fork_execl(self, track):
-        # ugh we set a default value because if we don't set bpm
-        # ugh find out if this has been fixed!
-        # when creating the track, we (sometimes???) get an insane tempo
-        # when using an external midiplayer, but not when using /dev/music
         track.prepend_bpm(60)
         self.create_midifile(track)
         if self.__child_pid:
@@ -93,10 +94,10 @@ class MidiFileSynth:
             elif e[0] == track.SET_PATCH:
                 v = v + mfutils.mf_program_change(e[1], e[2])
             elif e[0] == track.BENDER:
-                print "ugh todo: seq_bender for play_with_drvmidi"
+                print "FIXME todo: seq_bender for play_with_drvmidi"
                 #m.seq_bender(DEV, e[1], e[2])
             else:
-                raise error
+                raise "Corrupt track error"
         f = open(self.m_tmpfilename, "w")
         mfutils.MThd(f)
         f.write("MTrk")
