@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,12 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""
-This is NOT a generic rational number class, it includes
-only the features needed for the the soundcard and mpd
-module included in Solfege.
-"""
-
 import types
 
 def gcd(a, b):
@@ -29,6 +23,11 @@ def gcd(a, b):
     return a
 
 class Rat:
+    """
+    This is NOT a generic rational number class, it includes
+    only the features needed for the the soundcard and mpd
+    module included in Solfege.
+    """
     def __init__(self, num, den=1):
         assert type(num) == types.IntType
         assert type(den) == types.IntType
@@ -38,52 +37,52 @@ class Rat:
         return "(Rat %i/%i)" % (self.m_num, self.m_den)
     def __str__(self):
         return "(Rat %i/%i)" % (self.m_num, self.m_den)
-    def __add__(A, B):
-        assert isinstance(A, Rat)
+    def __add__(self, B):
+        assert isinstance(self, Rat)
         assert isinstance(B, Rat)
-        a = A.m_num * B.m_den + B.m_num * A.m_den 
-        b = A.m_den * B.m_den 
+        a = self.m_num * B.m_den + B.m_num * self.m_den
+        b = self.m_den * B.m_den
         g = gcd(a, b)
         return Rat(a/g, b/g)
-    def __sub__(A, B):
-        assert isinstance(A, Rat)
+    def __sub__(self, B):
+        assert isinstance(self, Rat)
         assert isinstance(B, Rat)
-        a = (A.m_num * B.m_den - B.m_num * A.m_den) 
-        b = A.m_den * B.m_den 
+        a = (self.m_num * B.m_den - B.m_num * self.m_den)
+        b = self.m_den * B.m_den
         g = gcd(a, b)
         return Rat(a/g, b/g)
-    def __mul__(A, B):
-        assert isinstance(A, Rat)
+    def __mul__(self, B):
+        assert isinstance(self, Rat)
         if type(B) == type(0):
-            g = gcd(A.m_num*B, A.m_den)
-            return Rat(A.m_num*B/g, A.m_den/g)
+            g = gcd(self.m_num*B, self.m_den)
+            return Rat(self.m_num*B/g, self.m_den/g)
         assert isinstance(B, Rat)
-        g = gcd(A.m_num*B.m_num, A.m_den*B.m_den)
-        return Rat(A.m_num*B.m_num/g, A.m_den*B.m_den/g)
-    def __rdiv__(A, B):
+        g = gcd(self.m_num*B.m_num, self.m_den*B.m_den)
+        return Rat(self.m_num*B.m_num/g, self.m_den*B.m_den/g)
+    def __rdiv__(self, B):
         """ called when integer / Rat
         """
         assert type(B) == types.IntType
-        assert isinstance(A, Rat)
-        a = B * A.m_den
-        b = A.m_num
+        assert isinstance(self, Rat)
+        a = B * self.m_den
+        b = self.m_num
         g = gcd(a, b)
         return Rat(a/g, b/g)
-    def __rmul__(A, B):
+    def __rmul__(self, B):
         """ called when integer * Rat
         """
-        assert isinstance(A, Rat)
+        assert isinstance(self, Rat)
         assert type(B) == types.IntType
-        a = A.m_num * B
-        g = gcd(a, A.m_den)
-        return Rat(a/g, A.m_den/g)
+        a = self.m_num * B
+        g = gcd(a, self.m_den)
+        return Rat(a/g, self.m_den/g)
     def __int__(self):
         return self.m_num / self.m_den
     def __hash__(self):
         return hash((self.m_num, self.m_den))
-    def __cmp__(A, B):
-        return cmp(1.0*A.m_num/A.m_den, 1.0*B.m_num/B.m_den)
-        
+    def __cmp__(self, B):
+        return cmp(1.0*self.m_num/self.m_den, 1.0*B.m_num/B.m_den)
+
 if __name__ == "__main__":
     A = Rat(3, 4)
     B = Rat(1, 4)
