@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,13 +16,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
-import gu, widgets
+import gu
+import inputwidgets
 import soundcard, mpd
 import dataparser
 
-import const, os, stat, random, utils, string
+import const, utils, string
 from i18n import _
-import statisticsviewer, lessonfile
 import types
 import cfg
 
@@ -90,7 +90,7 @@ class MelodicIntervallTeacher(Teacher):
             return self.ERR_CONFIGURE
         L, H = utils.adjust_low_high_to_irange(L, H, 
                      self.get_list('ask_for_intervalls_0'))
-            
+
         if self.m_timeout_handle:
             gtk.timeout_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
@@ -98,7 +98,7 @@ class MelodicIntervallTeacher(Teacher):
         if self.get_bool('config/picky_on_new_question') \
               and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
             return self.ERR_PICKY
-            
+
         self.q_status = const.QSTATUS_NO
         last_tonika = self.m_tonika
         last_question = self.m_question
@@ -148,11 +148,11 @@ class MelodicIntervallTeacher(Teacher):
         m = soundcard.Track()
         m.set_bpm(self.get_int('config/default_bpm'))
         m.set_patch(0, self.get_int('config/preferred_instrument'))
-        m.note(4, 0, self.m_tonika.semitone_pitch(), 
+        m.note(4, 0, self.m_tonika.semitone_pitch(),
                self.get_int('config/preferred_instrument_velocity'))
         for i in self.m_question:
-            t = t + i            
-            m.note(4, 0, t.semitone_pitch(), 
+            t = t + i
+            m.note(4, 0, t.semitone_pitch(),
                    self.get_int('config/preferred_instrument_velocity'))
         soundcard.synth.play_track(m)
 
@@ -225,7 +225,8 @@ You really should reastart the program now.""")
         try:
             mpd.play_music(self.m_P.get_music(),
                            self.m_P.get_tempo(),
-                           self.get_int('config/preferred_instrument'))
+                           self.get_int('config/preferred_instrument'),
+                           self.get_int('config/preferred_instrument_velocity'))
         except mpd.musicalpitch.InvalidNotenameException, n:
             gnome.ui.GnomeErrorDialog("In lessonfile '%s':\n Invalid notename: %s" % (
                 self.get_string('lessonfile'), n.m_notename) )
@@ -247,12 +248,12 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
     """
     def __init__(self, teacher, window, no_notebook=0):
         gtk.GtkVBox.__init__(self)
-        #cfg.ConfigUtils.__init__(self, exname)
-        cfg.ConfigUtils.__dict__['__init__'](self, teacher.m_exname)
+        cfg.ConfigUtils.__init__(self, teacher.m_exname)
+        #cfg.ConfigUtils.__dict__['__init__'](self, teacher.m_exname)
         self.m_key_bindings = {}
         self.m_t = teacher
         self.g_win = window
-        
+
         vbox = gtk.GtkVBox()
         vbox.set_spacing(gnome.uiconsts.PAD)
         vbox.set_border_width(gnome.uiconsts.PAD)
@@ -261,7 +262,7 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
         self.practise_box = gtk.GtkVBox()
         self.practise_box.show()
         vbox.pack_start(self.practise_box)
-        
+
         self.action_area = gtk.GtkHBox()
         self.action_area.set_usize(-1, self.get_int("gui/button_height"))
         self.action_area.show()
@@ -312,7 +313,7 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
             else:
                 self.g_statview.update()
     def get_pretty_name(self):
-       return string.replace(const.exercisedata[self.m_exname][0], '_', '')
+        return string.replace(const.exercisedata[self.m_exname][0], '_', '')
     def _add_auto_new_question_gui(self, box):
         hbox = gu.bHBox(box, gtk.FALSE)
         hbox.set_spacing(gnome.uiconsts.PAD_SMALL)
@@ -336,17 +337,17 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
 class IntervallGui(Gui):
     """
     Creates 'New intervall' and 'Repeat' buttons in the action_area.
-    """   
+    """
     def __init__(self, teacher, window):
         Gui.__init__(self, teacher, window)
-        
+
         self.g_input = None
 
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
         self.practise_box.set_spacing(gnome.uiconsts.PAD)
-        
+
         self.g_new_intervall = gu.bButton(self.action_area, _("New intervall"),
                                           self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("Repeat"),
@@ -358,7 +359,6 @@ class IntervallGui(Gui):
         This will be called by HarmonicIntervall and MelodicIntervall
         constructor
         """
-        import inputwidgets
         i = self.get_int('inputwidget')
         if i < len(inputwidgets.inputwidget_names):
             s = inputwidgets.inputwidget_names[i]
@@ -379,25 +379,23 @@ class IntervallGui(Gui):
     def setup_key_bindings(self):
         keys = ['minor2', 'major2', 'minor3', 'major3',
                 'perfect4', 'diminished5', 'perfect5', 'minor6',
-                'major6', 'minor7', 'major7', 'perfect8', 
+                'major6', 'minor7', 'major7', 'perfect8',
                 'minor9', 'major9', 'minor10', 'major10']
         self.m_key_bindings = {'new_ak': self.new_question,
                                'repeat_ak': self.m_t.play_question,
                                'give_up_ak': self.give_up}
         for idx in range(len(keys)):
             self.m_key_bindings['intervall_input/'+keys[idx]] = lambda idx=idx, self=self: self.click_on_intervall(1, idx+1, None)
-    def on_start_practise(self):
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
-            self.g_flashbar.flash(_("Click 'New intervall' to begin.")))
+
 
 class LessonbasedGui(Gui):
     def __init__(self, teacher, window):
         Gui.__init__(self, teacher, window)
     def get_pretty_name(self):
-       s = string.replace(const.exercisedata[self.m_exname][0], '_', '')
-       if self.get_string('lessoncollection') == 'solfege':
+        s = string.replace(const.exercisedata[self.m_exname][0], '_', '')
+        if self.get_string('lessoncollection') == 'solfege':
             return "%s - %s" % (s, self.get_string('lessonfile'))
-       else:
+        else:
             return "%s - %s/%s" % (s,
              self.get_string('lessoncollection'), self.get_string('lessonfile'))
 
