@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import __main__
 
 from i18n import _
 
@@ -22,12 +23,10 @@ import configureoutput
 import errno, sys
 import shutil
 
-import utils
-import const
 import soundcard, mpd
 import lessonfile
 import os
-import cfg
+import cfg, utils
 
 class SolfegeApp(cfg.ConfigUtils):
     def __init__(self, argv, ui):
@@ -40,19 +39,29 @@ class SolfegeApp(cfg.ConfigUtils):
         self.lessonfile_manager = lessonfile.LessonFileManager()
         self.setup_sound()
     def check_rcfile(self):
-        if cfg.get_string("app/version") < "0.7.34":
-            if configureoutput.WITH_GNOME:
-                fn = "~/.gnome/%s" % cfg.app_id
+        # The [app] version variable say  the oldest rc version
+        # this function can convert to a version this version of
+        # Solfege can handle.
+        #
+        # First figure out what file to replace
+        if configureoutput.WITH_GNOME:
+            fn = "~/.gnome/%s" % cfg.app_id
+        else:
+            if sys.platform == "win32":
+                fn = "~/solfegerc%s.%s"
             else:
-                if sys.platform == "win32":
-                    fn = "~/solfegerc%s.%s"
-                else:
-                    fn = "~/.solfegerc%s.%s"
-                fn = fn % (configureoutput.MAJOR_VERSION,
-                           configureoutput.MINOR_VERSION)
+                fn = "~/.solfegerc%s.%s"
+            fn = fn % (configureoutput.MAJOR_VERSION,
+                       configureoutput.MINOR_VERSION)
+        if sys.platform == "win32":
+            ver = "1.1.3"
+        else:
+            ver = "0.7.34"
+        if utils.compare_version_strings(
+                 cfg.get_string("app/version"), ver) == -1:
             if os.path.isfile("debian-solfege.py.in"):
                 # we are running the program from the source dir
-                # without installing
+                # without installing. Also windows users go here.
                 shutil.copyfile("default.config", os.path.expanduser(fn))
                 print "\nSorry, but you have to start Solfege one more time."
                 print "I just installed a new", fn
@@ -70,6 +79,15 @@ class SolfegeApp(cfg.ConfigUtils):
                                os.path.expanduser("~/.gnome/%s" % cfg.app_id))
                     print "You have to start Solfege once more."
                     sys.exit(-1)
+
+        if __main__.rc_copied:
+            # some checks if we have upgraded an old rcfile from 1.0.x
+            # or 1.1.x 
+            if cfg.get_string("id-tone/new_ak") == "":
+                cfg.set_string("id-tone/new_ak", "<ctrl>n")
+            if cfg.get_string("id-tone/give_up_ak") == "":
+                cfg.set_string("id-tone/give_up_ak", "<ctrl>g")
+            cfg.set_bool("gui/development_menu_visible", 0)
         cfg.set_string('app/version', configureoutput.VERSION_STRING)
     def check_statistics(self):
         # the devel series are fresh and no history to care about
@@ -85,9 +103,15 @@ class SolfegeApp(cfg.ConfigUtils):
             if os.path.exists(os.path.expanduser("~/.solfege0.7/identify-scale")):
                 shutil.rmtree(os.path.expanduser("~/.solfege0.7/identify-scale/"))
     def setup_sound(self):
+        if sys.platform == 'win32' and \
+                    cfg.get_string("sound/type") == "sequencer-device":
+            # just in case c:\home\solfegercX.Y is wrong
+            cfg.set_string("sound/type", "winsynth")
         if '--no-sound' in self.m_argv \
            or cfg.get_string("sound/type") == "fake-synth":
             soundcard.initialise_using_fake_synth('--verbose-sound-init' in self.m_argv)
+        elif cfg.get_string("sound/type") == "winsynth":
+            soundcard.initialise_winsynth(verbose_init='--verbose-sound-init' in self.m_argv)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
                     cfg.get_string("sound/commandline"),
@@ -116,12 +140,8 @@ from the 'Sound' page of
 the preferences window.
 """)
                 else:
-                    self.popup_sound_init_error_dialog(e)
-            except Exception, e:
-                self.m_ui.display_error_message(
-"""Error while trying to initialise %s:
-%s""" % (cfg.get_string("sound/device_file"), e))
-    def popup_sound_init_error_dialog(self, e):
+                    self.display_sound_init_error_message(e)
+    def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
             """%s""" % e)
@@ -145,11 +165,13 @@ configured. You can check the 'Sound' page in the
 preferences window, but I don't think anything there
 can help you. (This program need better sound init
 code to handle situations like this.)"""
- % e)
+ % errno.errorcode[e.errno])
     def play_happy_sound(self):
-        mpd.play_music(r"\staff\relative c'{c16 e g a}", 180, 8)
+        mpd.play_music(r"\staff\relative c'{c16 e g a}", 180, 8,
+               cfg.get_int('config/preferred_instrument_velocity'))
     def play_sad_sound(self):
-        mpd.play_music(r"\staff\relative c'{<c,,8 cis>", 180, 58)
+        mpd.play_music(r"\staff\relative c'{<c,,8 cis>", 80, 58,
+               cfg.get_int('config/preferred_instrument_velocity'))
     def please_help_me(self):
         if self.m_ui.m_viewer != 'docviewer':
             self.handle_href('%s-help.html' % self.m_ui.m_viewer)
