@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,9 @@
 import gtk, gnome
 import gu, widgets
 import soundcard, mpd, mpd.musicdisplayer
-import abstract, const, lessonfile, statistics
-import random, string
+import abstract, const, lessonfile
+import string
+import utils
 from i18n import _
 
 class Teacher(abstract.LessonbasedTeacher):
@@ -139,8 +140,8 @@ class Gui(abstract.LessonbasedGui):
         self.g_toptone_status = gtk.GtkLabel("")
         table.attach(self.g_toptone_status, 4, 5, 4, 5,
                      xoptions=gtk.FILL, yoptions=0)
-        
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.set_usize(150, -1)
         hbox.pack_start(self.g_music_displayer)
 
@@ -157,7 +158,7 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.config_box.set_spacing(gnome.uiconsts.PAD)
+        self.config_box.set_spacing(gnome.uiconsts.PAD_SMALL)
         self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
             self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
         self.g_lessonfile_selector.show()
@@ -268,7 +269,7 @@ class Gui(abstract.LessonbasedGui):
             return
         clef = mpd.select_clef(self.m_t.m_P.get_music())
         fontsize = self.get_int('config/feta_font_size=20')
-        self.g_music_displayer.display(r"\staff{\clef %s; <%s>}" % (clef, self.m_t.m_P.get_music()), fontsize)
+        self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music()), fontsize)
         self.g_type_status.set_text(self.m_t.m_P.get_chordtype())
         i = self.m_t.m_P.get_inversion()
         if i == 0:
