@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome.uiconsts
-import gu, widgets
+import random
+
+import gu, widgets, utils
 import mpd, mpd.musicdisplayer, soundcard
-import abstract, const, random
+import abstract, const
 from i18n import _
 
 
@@ -37,7 +39,7 @@ class Teacher(abstract.Teacher):
         if self.m_timeout_handle:
             gtk.timeout_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
-            
+
         if self.get_bool('config/picky_on_new_question') \
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
              return Teacher.ERR_PICKY
@@ -62,6 +64,8 @@ class Teacher(abstract.Teacher):
         self.q_status = const.QSTATUS_NEW
         return self.OK
     def play_question(self):
+        if self.q_status == const.QSTATUS_NO:
+            return
         low_instr, low_vel, high_instr, high_vel = self.get_instrument_config(2)
         m = soundcard.Track()
         m.set_patch(0, low_instr)
@@ -124,10 +128,10 @@ class Gui(abstract.Gui):
         ##############
         self.practise_box.set_spacing(gnome.uiconsts.PAD)
         hbox = gu.bHBox(self.practise_box)
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.clear()
         hbox.pack_start(self.g_music_displayer)
-        
+
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
@@ -236,6 +240,8 @@ class Gui(abstract.Gui):
         self.g_last_intervall_up.set_sensitive(button.get_data('idir') in ['harmonic', 'up', 'up/down'])
         self.g_last_intervall_down.set_sensitive(button.get_data('idir') in ['up/down', 'down'])
     def guess_answer(self, g):
+        if self.m_t.q_status == const.QSTATUS_NO:
+            return
         if self.m_t.q_status == const.QSTATUS_SOLVED:
             if self.m_t.guess_answer(g):
                 self.g_flashbar.flash(_("Correct, but you have already solved this question"))
@@ -270,7 +276,7 @@ class Gui(abstract.Gui):
             self.g_new.set_sensitive(gtk.TRUE)
             self.show_intervalls()
     def show_intervalls(self, widget=None):
-        tv = [self.get_string('first_intervall_type'), 
+        tv = [self.get_string('first_intervall_type'),
                 self.get_string('last_intervall_type')]
         clefs = {}
         music = {}
@@ -280,9 +286,9 @@ class Gui(abstract.Gui):
             clefs[x] = mpd.select_clef(music[x])
             if tv[x] == 'harmonic':
                 music[x] = "< %s >" % music[x]
-        m = r"\staff{ \clef %s; %s |" % (clefs[0], music[0])
+        m = r"\staff{ \clef %s %s |" % (clefs[0], music[0])
         if clefs[0] != clefs[1]:
-            m = m + r"\clef %s;" % clefs[1]
+            m = m + r"\clef %s" % clefs[1]
         m = m + music[1]
         self.g_music_displayer.display(m, 
               self.get_int('config/feta_font_size=20'))
