@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, gnome
+import sys
+import gtk, gnome, gnome.ui
 import gu, mpd
 import configureoutput
 import widgets
@@ -91,7 +92,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             self.get_string('user/lowest_pitch'))
         self.g_lowest_singable.g_entry.connect('changed', self.on_changed)
         table.attach(self.g_lowest_singable, 1, 2, 1, 2)
-        nc = widgets.NotenameRangeController(
+        widgets.NotenameRangeController(
                   self.g_lowest_singable, self.g_highest_singable,
                   mpd.LOWEST_NOTENAME, mpd.HIGHEST_NOTENAME)
 
@@ -110,7 +111,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         vbox = gtk.GtkVBox()
         vbox.set_border_width(gnome.uiconsts.PAD)
         self.append_page(vbox, gtk.GtkLabel(_("Gui")))
- 
+
         hbox = gu.bHBox(vbox, gtk.FALSE)
         hbox.set_spacing(gnome.uiconsts.PAD)
 
@@ -121,7 +122,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         frame_vbox.set_border_width(gnome.uiconsts.PAD)
         frame.add(frame_vbox)
         frame_hbox = gu.bHBox(frame_vbox)
- 
+
         self.g_toolbar_icons = gu.RadioButton(None, _("Icons"), self.on_changed)
         frame_hbox.pack_start(self.g_toolbar_icons, gtk.FALSE)
         self.g_toolbar_text = gu.RadioButton(self.g_toolbar_icons, _("Text"), self.on_changed)
@@ -213,13 +214,19 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         self.g_autorepeat_if_wrong = gtk.GtkCheckButton(_("Repeat question if the answer was wrong"))
         self.g_autorepeat_if_wrong.set_active(self.get_bool('config/auto_repeat_question_if_wrong_answer'))
         vbox.pack_start(self.g_autorepeat_if_wrong, gtk.FALSE)
- 
+
         self.g_picky_on_new_question.connect('clicked', self.on_changed)
         self.g_autorepeat_if_wrong.connect('clicked', self.on_changed)
 
         #########
         # sound #
         #########
+        if sys.platform == 'win32':
+            self.create_win32_sound_page()
+        else:
+            self.create_linux_sound_page()
+        self.show_all()
+    def create_linux_sound_page(self):
         vbox = gtk.GtkVBox()
         vbox.set_border_width(gnome.uiconsts.PAD)
         self.append_page(vbox, gtk.GtkLabel(_("Sound setup")))
@@ -246,7 +253,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         hbox.pack_start(self.g_synth_num, gtk.FALSE)
 
         hbox = gu.bHBox(vbox, gtk.FALSE)
-        self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio, 
+        self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
              _("Use external midiplayer"), None)
         hbox.pack_start(self.g_midiplayer_radio, gtk.FALSE)
         combo = gtk.GtkCombo()
@@ -262,13 +269,16 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             self.g_device_radio.set_active(gtk.TRUE)
         else:
             self.g_fakesynth_radio.set_active(gtk.TRUE)
- 
+
         # checkbox to enable awe support
         self.g_awe_checkbutton = gtk.GtkCheckButton(_("My sound card is Sound Blaster AWE32, AWE64 or pnp32"))
         self.g_awe_checkbutton.set_active(self.get_string('sound/card_info') == 'awe')
         if not configureoutput.HAVE_LINUX_AWE_VOICE_H:
             self.g_awe_checkbutton.set_sensitive(gtk.FALSE)
         vbox.pack_start(self.g_awe_checkbutton)
+
+        gu.bButton(vbox, _("Sound test. Hit 'Apply' before testing."), self.on_sound_test)
+
         self.g_fakesynth_radio.connect('clicked', self.on_changed)
         self.g_midiplayer_radio.connect('clicked', self.on_changed)
         self.g_device_radio.connect('clicked', self.on_changed)
@@ -276,15 +286,57 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         self.g_device_entry.connect('changed', self.on_changed)
         self.g_synth_num.connect('changed', self.on_changed)
         self.g_awe_checkbutton.connect('clicked', self.on_changed)
-        self.show_all()
-    def on_sel_help(self, nr):
-        for x in self.g_he.keys():
-            if x == nr:
-                self.g_he[x].set_sensitive(gtk.TRUE)
-            else:
-                self.g_he[x].set_sensitive(gtk.FALSE)
-        self.set_modified(gtk.TRUE)
+    def create_win32_sound_page(self):
+        vbox = gtk.GtkVBox()
+        vbox.set_border_width(gnome.uiconsts.PAD)
+        self.append_page(vbox, gtk.GtkLabel(_("Sound setup")))
+        txt = gtk.GtkLabel(_("""Solfege has two ways to play music. It is recommended to use Windows multimedia output. Support for external midiplayer is only available because this was the only way to get sound on Windows in earlier versions of this program."""))
+        txt.set_line_wrap(1)
+        txt.set_justify(gtk.JUSTIFY_FILL)
+        txt.set_alignment(0.0, 0.0)
+        vbox.pack_start(txt, gtk.FALSE)
+        self.g_fakesynth_radio = gu.RadioButton(None, _("No sound"), None)
+        vbox.pack_start(self.g_fakesynth_radio, gtk.FALSE)
+        hbox = gu.bHBox(vbox, gtk.FALSE)
+        self.g_device_radio = gu.RadioButton(self.g_fakesynth_radio,
+              _("Windows multimedia output"), None)
+        hbox.pack_start(self.g_device_radio, gtk.FALSE)
+
+        hbox = gu.bHBox(vbox, gtk.FALSE)
+        self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
+             _("Use external midiplayer"), None)
+        hbox.pack_start(self.g_midiplayer_radio, gtk.FALSE)
+        combo = gtk.GtkCombo()
+        combo.set_popdown_strings(('midiplayer.exe %s',
+                                   'timidity -idqq %s',
+                                   'playmidi -f %s'))
+        self.g_midiplayer_entry = combo.entry
+        hbox.pack_start(combo, gtk.FALSE)
+        self.g_midiplayer_entry.set_text(self.get_string("sound/commandline"))
+        if self.get_string("sound/type") == "external-midiplayer":
+            self.g_midiplayer_radio.set_active(gtk.TRUE)
+        elif self.get_string("sound/type") == "winsynth":
+            self.g_device_radio.set_active(gtk.TRUE)
+        else:
+            self.g_fakesynth_radio.set_active(gtk.TRUE)
+
+        gu.bButton(vbox, _("Sound test. Hit 'Apply' before testing."), self.on_sound_test)
+
+        self.g_fakesynth_radio.connect('clicked', self.on_changed)
+        self.g_midiplayer_radio.connect('clicked', self.on_changed)
+        self.g_device_radio.connect('clicked', self.on_changed)
+        self.g_midiplayer_entry.connect('changed', self.on_changed)
+    def on_sound_test(self, w):
+        mpd.play_music(r"""
+        \staff\relative c{
+          c16 e g c e, g c e g, c e g c4
+        }
+        \staff{
+          c4 e g8 e c4
+        }
+        """, 130, 0, 100)
     def on_help(self, *v):
+        #FIXME It is stupid to display this help in the main window.
         self.m_app.handle_href("preferences-window.html")
     def on_changed(self, _o=None):
         if self._is_alive:
@@ -350,7 +402,6 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
                 self.m_app.m_ui.set_policy(0, 0, 1)
             self.set_string("config/web_browser", self.g_web_browser.get_text())
             self.set_string("config/mua", self.g_mail_program.get_text())
-            d = self.m_app.m_ui.get_dock_item_by_name("Menubar")
             self.set_bool('gui/development_menu_visible',
                           self.g_development_menu_visible.active)
             if self.get_bool('gui/development_menu_visible'):
@@ -358,7 +409,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             else:
                 self.m_app.m_ui.get_dock_item_by_name("Menubar").children()[0].children()[1].hide()
         if pagenum == 3:
-            self.set_bool('config/picky_on_new_question', 
+            self.set_bool('config/picky_on_new_question',
                           self.g_picky_on_new_question.active)
             self.set_bool('config/auto_repeat_question_if_wrong_answer',
                           self.g_autorepeat_if_wrong.active)
@@ -369,18 +420,22 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
                 soundcard.initialise_external_midiplayer(
                       self.g_midiplayer_entry.get_text())
             elif self.g_device_radio.active:
-                if configureoutput.HAVE_LINUX_AWE_VOICE_H and \
+                if sys.platform != 'win32' and configureoutput.HAVE_LINUX_AWE_VOICE_H and \
                     self.g_awe_checkbutton.active:
                       card_info = "awe"
                 else:
                      card_info = ""
                 try:
-                    soundcard.initialise_devicefile(
-                      self.g_device_entry.get_text(),
-                      self.g_synth_num.get_value_as_int(),
-                      card_info)
+                    if sys.platform == 'win32':
+                        soundcard.initialise_winsynth()
+                    else:
+                        soundcard.initialise_devicefile(
+                            self.g_device_entry.get_text(),
+                            self.g_synth_num.get_value_as_int(),
+                            card_info)
                 except (soundcard.SoundInitException, OSError), e:
-                    self.m_app.popup_sound_init_error_dialog(e)
+                    self.m_app.display_sound_init_error_message(e)
+		    return
             elif self.g_fakesynth_radio.active:
                 soundcard.initialise_using_fake_synth(0)
             else:
@@ -392,13 +447,14 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             else:
                 assert self.g_fakesynth_radio.active
                 self.set_string("sound/type", "fake-synth")
-            self.set_string("sound/device_file", self.g_device_entry.get_text())
-            self.set_string("sound/card_info", card_info)
-            if soundcard.synth.m_type_major == "OSS":
-                self.set_int("sound/synth_number", soundcard.synth.m_devnum)
-                # we set the spin just in case m_devnum was changed by the
-                # soundcard setup code, if it was out of range
-                self.g_synth_num.set_value(soundcard.synth.m_devnum)
+            if sys.platform != 'win32':
+                self.set_string("sound/device_file", self.g_device_entry.get_text())
+                self.set_string("sound/card_info", card_info)
+                if soundcard.synth.m_type_major == "OSS":
+                    self.set_int("sound/synth_number", soundcard.synth.m_devnum)
+                    # we set the spin just in case m_devnum was changed by the
+                    # soundcard setup code, if it was out of range
+                    self.g_synth_num.set_value(soundcard.synth.m_devnum)
             self.set_string("sound/commandline",
                             self.g_midiplayer_entry.get_text())
         if pagenum == -1:
