@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
-import abstract, idbyname, const, mpd, gu, statisticsviewer, widgets
+import abstract, idbyname, const, gu, statisticsviewer, widgets
 from i18n import _
 import soundcard, mpd, mpd.musicdisplayer
+import utils
 
 class Teacher(idbyname.Teacher):
     def __init__(self, exname, app):
@@ -26,7 +27,8 @@ class Teacher(idbyname.Teacher):
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
-        tracklist = mpd.music_to_tracklist(self.m_P.get_music())
+        tracklist = mpd.music_to_tracklist(self.m_P.get_music(),
+                 self.get_int('config/preferred_instrument_velocity'))
         l, lv, m, mv, h, hv = self.get_instrument_config(3)
         tracklist[0].prepend_patch(0, h)
         t = tracklist[0]
@@ -47,10 +49,10 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.set_usize(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
-        
+
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
