@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
-import gu, widgets, inputwidgets
+import gu, widgets
 import abstract, const, mpd
 import statistics, statisticsviewer
-import lessonfile, random
-import utils, string
+import lessonfile
+import string
 from i18n import _
 
 
@@ -32,7 +32,7 @@ class Teacher(abstract.LessonbasedTeacher):
         abstract.LessonbasedTeacher.__init__(self, exname, app, use)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
         self.parse_lessonfile()
-        
+
         self.m_statistics = statistics.LessonStatistics(self)
     def give_up(self):
         self.q_status = const.QSTATUS_GIVE_UP
@@ -100,6 +100,7 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
+        self.config_box.set_spacing(gnome.uiconsts.PAD_SMALL)
         self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
             self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
         self.g_lessonfile_selector.show()
@@ -174,6 +175,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.clear()
             self.m_t.play_question()
     def on_start_practise(self):
+        self.m_t.m_statistics.reset_session()
         gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New' to begin.")))
     def on_end_practise(self):
