@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,39 +15,42 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import random
+
 import gtk, gnome
-import abstract, gu, const, mpd, mpd.musicdisplayer, random, utils
+import abstract, gu, const, mpd, mpd.musicdisplayer
+import utils
 import statistics, statisticsviewer
 from i18n import _
 
-
+scaledata = {
+    'ionian': ('[c8 d][e f][g a][b c]|[c b][a g][f e][d c]',
+               _("Ionian"), 'c', 0, 0),
+    'dorian': ('[c8 d][es f][g a][bes c]|[c bes][a g][f es][d c]',
+               _("Dorian"), 'bes', 1, 0),
+    'phrygian': ('[c8 des][es f][g as][bes c]|[c bes][as g][f es][des c]',
+                _("Phrygian"), 'as', 2, 0),
+    'lydian': ('[c8 d][e fis][g a][b c]|[c b][a g][fis e][d c]',
+               _("Lydian"), 'g', 3, 0),
+    'mixolydian': ('[c8 d][e f][g a][bes c]|[c bes][a g][f e][d c]',
+                   _("Mixolydian"), 'f', 0, 1),
+    'aeolian': ('[c8 d][es f][g as][bes c]|[c bes][as g][f es][d c]',
+                _("Aeolian"), 'es', 1, 1),
+    'locrian': ('[c8 des][es f][ges as][bes c]|[c bes][as ges][f es][des c]',
+                _("Locrian"), 'des', 2, 1),
+    'harmonic_minor': ('[c8 d][es f][g as][b c]|[c b][as g][f es][d c]',
+                       _("Harmonic minor"), 'es', 3, 1),
+    'melodic_minor': ('[c8 d][es f][g a][b c]|[c bes][as g][f es][d c]',
+                      _("Melodic minor"), 'es', 0, 2)
+}
 class Teacher(abstract.Teacher):
     OK = 0
     ERR_NO_SCALES = 1
     ERR_PICKY = 2
     def scale_key_to_name(self, key):
-        return {        'ionian': _("Ionian"),
-                        'dorian': _("Dorian"),
-                      'phrygian': _("Phrygian"),
-                        'lydian': _("Lydian"),
-                    'mixolydian': _("Mixolydian"),
-                       'aeolian': _("Aeolian"),
-                       'locrian': _("Locrian"),
-                'harmonic_minor': _("Harmonic minor"),
-                 'melodic_minor': _("Melodic minor")}[key]
+        return scaledata[key][1]
     def __init__(self, exname, app):
         abstract.Teacher.__init__(self, exname, app)
-        self._scaledb = {
-               'ionian': '[c8 d][e f][g a][b c]|[c b][a g][f e][d c]',
-               'dorian': '[c8 d][es f][g a][bes c]|[c bes][a g][f es][d c]',
-               'phrygian': '[c8 des][es f][g as][bes c]|[c bes][as g][f es][des c]',
-               'lydian': '[c8 d][e fis][g a][b c]|[c b][a g][fis e][d c]',
-               'mixolydian': '[c8 d][e f][g a][bes c]|[c bes][a g][f e][d c]',
-               'aeolian': '[c8 d][es f][g as][bes c]|[c bes][as g][f es][d c]',
-               'locrian': '[c8 des][es f][ges as][bes c]|[c bes][as ges][f es][des c]',
-               'harmonic_minor': '[c8 d][es f][g as][b c]|[c b][as g][f es][d c]',
-               'melodic_minor': '[c8 d][es f][g a][b c]|[c bes][as g][f es][d c]'
-             }
         self._scale = None
         self.m_statistics = statistics.Statistics(self)
         self.m_statistics.key_to_pretty_name = self.scale_key_to_name
@@ -64,7 +67,7 @@ class Teacher(abstract.Teacher):
              return Teacher.ERR_PICKY
         self.q_status = const.QSTATUS_NO
         active_scales = []
-        for s in self._scaledb.keys():
+        for s in scaledata.keys():
             if self.get_bool(s):
                 active_scales.append(s)
         if active_scales:
@@ -76,17 +79,8 @@ class Teacher(abstract.Teacher):
             return self.ERR_NO_SCALES
     def get_mpd_string(self):
         assert self._scale
-        t = {           'ionian': "c",
-                        'dorian': "bes",
-                      'phrygian': "as",
-                        'lydian': "g",
-                    'mixolydian': "f",
-                       'aeolian': "es",
-                       'locrian': "des",
-                'harmonic_minor': "es",
-                 'melodic_minor': "es"}[self._scale]
-        return r"\staff\transpose %s\relative c'{ \clef violin; \key %s \major; %s }" \
-                   % (self.m_tonika.str(), t, self._scaledb[self._scale])
+        return r"\staff\transpose %s\relative c'{ \clef violin \key %s \major %s }" \
+                   % (self.m_tonika.str(), scaledata[self._scale][2], scaledata[self._scale][0])
     def play(self):
         if self.q_status == const.QSTATUS_NO:
             return
@@ -94,8 +88,9 @@ class Teacher(abstract.Teacher):
             bpm = self.get_int('default_bpm')
         else:
             bpm = self.get_int('config/default_bpm')
-        mpd.play_music(self.get_mpd_string(), bpm, 
-                       self.get_int('config/preferred_instrument'))
+        mpd.play_music(self.get_mpd_string(), bpm,
+                       self.get_int('config/preferred_instrument'),
+                       self.get_int('config/preferred_instrument_velocity'))
     def play_slowly(self):
         if self.q_status == const.QSTATUS_NO:
            return
@@ -104,7 +99,8 @@ class Teacher(abstract.Teacher):
         else:
             bpm = self.get_int('config/slow_bpm')
         mpd.play_music(self.get_mpd_string(), bpm,
-                       self.get_int('config/preferred_instrument'))
+                       self.get_int('config/preferred_instrument'),
+                       self.get_int('config/preferred_instrument_velocity'))
     def guess_answer(self, answer):
         """
         Return: 1 if correct, None if not
@@ -126,7 +122,7 @@ class Teacher(abstract.Teacher):
             self.set_string(k, dict[k])
         if dict.has_key('scales'):
             scales = eval(dict['scales'])
-            for s in self._scaledb.keys():
+            for s in scaledata.keys():
                 self.set_bool(s, s in scales)
 
 class Gui(abstract.Gui):
@@ -140,7 +136,7 @@ class Gui(abstract.Gui):
         ################
         # practise_box #
         ################
-        self.g_score_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_score_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_score_displayer.set_usize(-1, 150)
         self.practise_box.pack_start(self.g_score_displayer)
 
@@ -148,20 +144,15 @@ class Gui(abstract.Gui):
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
         self.practise_box.set_spacing(gnome.uiconsts.PAD)
- 
+
         self.table = gtk.GtkTable(3, 3, gtk.TRUE)
         self.practise_box.pack_start(self.table, gtk.FALSE)
         self.g_scale_checkbuttons = {}
-        self.ScaleButton('ionian', 0, 0)
-        self.ScaleButton('dorian', 1, 0)
-        self.ScaleButton('phrygian', 2, 0)
-        self.ScaleButton('lydian', 3, 0)
-        self.ScaleButton('mixolydian', 0, 1)
-        self.ScaleButton('aeolian', 1, 1)
-        self.ScaleButton('locrian', 2, 1)
-        self.ScaleButton('harmonic_minor', 3, 1)
-        self.ScaleButton('melodic_minor', 0, 2)
-
+        for k in scaledata.keys():
+            b = gtk.GtkButton(scaledata[k][1])
+            b.connect('clicked', self.on_scale_click, k)
+            self.table.attach(b, scaledata[k][3], scaledata[k][3]+1,
+                              scaledata[k][4], scaledata[k][4]+1)
         self.g_new = gu.bButton(self.action_area, _("New scale"),
                                    self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("Repeat scale"),
@@ -177,6 +168,16 @@ class Gui(abstract.Gui):
         ##############
         # config_box #
         ##############
+        self.config_box.set_spacing(gnome.uiconsts.PAD)
+        frame = gtk.GtkFrame(_("Ask for these scales:"))
+        self.config_box.pack_start(frame, gtk.FALSE)
+        table = gtk.GtkTable(4, 3)
+        table.set_border_width(gnome.uiconsts.PAD_SMALL)
+        frame.add(table)
+        for k in scaledata.keys():
+            b = gu.nCheckButton(self.m_exname, k, scaledata[k][1], default_value=1)
+            table.attach(b, scaledata[k][3], scaledata[k][3]+1,
+                         scaledata[k][4], scaledata[k][4]+1)
         frame = gtk.GtkFrame(_("Override global settings"))
         self.config_box.pack_start(frame, gtk.FALSE)
         vbox = gtk.GtkVBox()
@@ -244,20 +245,8 @@ class Gui(abstract.Gui):
             self.g_flashbar.flash(_("You have to solve this question first."))
         else:
             raise "NEVER REACH THIS!"
-    def ScaleButton(self, scalename, x, y):
-        button = gtk.GtkButton()
-        button.connect('clicked', self.on_scale_click, scalename)
-        box = gtk.GtkHBox()
-        button.add(box)
-
-        self.g_scale_checkbuttons[scalename] = chk \
-	    = gu.nCheckButton(self.m_exname, scalename, default_value=1)
-        box.pack_start(chk, gtk.FALSE)
-        L = gtk.GtkLabel(self.m_t.scale_key_to_name(scalename))
-        L.set_alignment(0.0, 0.0)
-        box.pack_start(L)
-        self.table.attach(button, x, x+1, y, y+1)
     def on_start_practise(self):
+        self.m_t.m_statistics.reset_session()
         self.g_score_displayer.clear()
         gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
            self.g_flashbar.flash(_("Click 'New scale' to begin.")))
