@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,14 @@ import gtk, GDK, gnome.ui, types
 from i18n import _
 import mpd
 import soundcard
-import gu, cfg
+import cfg
+import configureoutput
+
+def _f(x):
+    if x < 100:
+        return 0
+    x = x - 100
+    return x / 2
 
 class PianoKeyboard(gnome.ui.GnomeCanvas):
     def __init__(self, lowest_tone, highest_tone, size):
@@ -59,6 +66,7 @@ class PianoKeyboard(gnome.ui.GnomeCanvas):
         for x in range(len(self.m_blacks)):
             if self.m_blacks[x]:
                 g = self.m_keyboard.add('group')
+                #ugh FIXME
                 #g.add('rect',
                 #      x1=(x+0.65)*self.m_w, y1=0,
                 #      x2=(x+1.35)*self.m_w, y2=self.m_h2,
@@ -68,12 +76,8 @@ class PianoKeyboard(gnome.ui.GnomeCanvas):
                       x2=(x*100+135)*self.m_w / 100, y2=self.m_h2,
                       fill_color='black', outline_color='black')
                 g.connect('event', self.on_event, self.m_blacks[x])
-        self.set_usize(len(self.m_whites)*self.m_w+1, self.m_h+1)#ugh
-        # I do not really understand the geometry of the GnomeCanvas...
-        # ugh avoid floating point division because LC_ALL=no_NO cause
-        # veird problems. This will be fixed in gnome-python-1.4
-        self.m_keyboard.move(-len(self.m_whites)*self.m_w * 100 / 264, 0)
-        #self.m_keyboard.move(-len(self.m_whites)*self.m_w/2.64, 0)
+        self.set_usize(len(self.m_whites)*self.m_w+1, self.m_h+1)
+        self.set_scroll_region(0, 0, len(self.m_whites)*self.m_w+1, self.m_h+1)
     def on_event(self, group, event, midi_int):
         if event.type == GDK.BUTTON_PRESS:
             self.on_button_press_event(group, event, midi_int)
@@ -98,7 +102,9 @@ class PianoOctaveWithAccelName(PianoKeyboard):
                 mpd.notename_to_int(['cis', 'dis', 'fis', 'gis', 'ais'][x]))
     def on_button_press_event(self, group, event, midi_int):
         if event.button == 3:
-            soundcard.play_note(0, 4, 0, midi_int, 80)
+            soundcard.play_note(cfg.get_int('config/preferred_instrument'),
+                           4, 0, midi_int,
+                           cfg.get_int('config/preferred_instrument_velocity'))
         elif event.button == 1:
             self.m_callback(mpd.int_to_notename(midi_int))
 
@@ -176,7 +182,7 @@ class IntervallButtonsWidget(gtk.GtkTable):
         self.new_int_button(_("Minor\nsecond"), 1, 0, 1, 0, 2)
         self.new_int_button(_("Major\nsecond"),  2, 0, 1, 2, 4)
         self.new_int_button(_("Minor\nthird"),   3, 0, 1, 4, 6)
-        self.new_int_button(_("Major\nthird"),    4, 0, 1, 6, 8)        
+        self.new_int_button(_("Major\nthird"),    4, 0, 1, 6, 8)
         self.new_int_button(_("Perfect\nfourth"),    5, 1, 2, 0, 2)
         self.new_int_button(_("Diminished\nfifth"),    6, 1, 2, 2, 4)
         self.new_int_button(_("Perfect\nfifth"),    7, 1, 2, 4, 6)
@@ -197,7 +203,7 @@ class IntervallButtonsWidget(gtk.GtkTable):
         # the buttons
         b = gtk.GtkButton(txt)
         self.attach(b, x1, x2, y1, y2)
-        b.connect('clicked', 
+        b.connect('clicked',
                   lambda s, nr=nr, self=self:self.m_callback(1, nr, None))
         b.set_data('intervall', nr)
         b.connect('event', self._abc)
@@ -246,20 +252,18 @@ class AbstractGuitarWidget(gnome.ui.GnomeCanvas):
             self.m_ylist.append(tmp)
         for x in self.m_fretdist:
             self.m_neckl = self.m_neckl + x
+        self.m_neckl = self.m_neckl + 2
         self.m_neckw = self.m_neckborder \
                        + (self.m_numstring-1)*self.m_stringdist \
                        + 1 + self.m_neckborder
-        self.m_xdelta = 170
-        self.m_guitar.move(-self.m_xdelta, 0)
         self.m_guitar.add('rect', x1=0, x2=self.m_neckl,
                           y1=0, y2=self.m_neckw,
-                      #outline_color='black',
                       fill_color='black')
         # det frste bndet er ekstra tykt
         px = self.m_fretdist[0]
         self.m_guitar.add('rect', x1=px, x2=px+1,
                           y1=0, y2=self.m_neckw, fill_color='white')
-        self.m_guitar.add('rect', x1=px+1, x2=px+5, 
+        self.m_guitar.add('rect', x1=px+1, x2=px+5,
                           y1=0, y2=self.m_neckw, fill_color='gray')
         self.m_guitar.add('rect', x1=px+5, x2=px+6,
                           y1=0, y2=self.m_neckw, fill_color='dark gray')
@@ -302,12 +306,11 @@ class AbstractGuitarWidget(gnome.ui.GnomeCanvas):
                   y2=self.m_neckborder+y*self.m_stringdist+2,
                   fill_color='dark gray')
 
-
-
-        self.set_usize(self.m_neckl+20, self.m_neckw)
+        self.set_usize(self.m_neckl, self.m_neckw)
+        self.set_scroll_region(0, 0, self.m_neckl, self.m_neckw)
         self.show()
     def forget_last_tone(self):
-        #ugh this could be shared with the other instrument widgets.
+        #FIXME this could be shared with the other instrument widgets.
         self.m_clicked_tones.pop()
     def white_dot(self, x, y):
         dot = self.m_guitar.add('group')
@@ -364,8 +367,8 @@ class AbstractGuitarWidget(gnome.ui.GnomeCanvas):
         for idx in range(len(self.m_stringtuning)):
             if self.m_stringtuning[idx] <= note < self.m_stringtuning[idx] + len(self.m_fretdist):
                 self._set_mark(note - self.m_stringtuning[idx], idx)
-        #ugh Do I need this because of a bug in GnomeCanvas?
-        #if self.aa:
+        #FIXME Do I need this because of a bug in GnomeCanvas or because
+        # I don't understand the GnomeCanvas?
         self.queue_draw()
     def _set_mark(self, x, y):
         assert not self.m_mark_dict.has_key((x, y))
@@ -396,7 +399,7 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
         self.m_callback = callback
         self.m_clicked_tones = []
         self.m_mark_dict = {}
-        self.m_notenames_norwegian = (("g,", "bes,", "des", "e", 
+        self.m_notenames_norwegian = (("g,", "bes,", "des", "e",
                  "g", "bes", "des'", "e'", "g'", "bes'", "des''", "e''",
                  "g''", "bes''", "des'''", "e'''", "g'''", "bes'''", "des''''"),
                 ("f,", "aes,", "b,", "d",
@@ -415,7 +418,7 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
                 ("e,", "g,", "bes,", "des",
                  "e", "g", "bes", "des'", "e'", "g'", "bes'", "des''", "e''",
                  "g''", "bes''", "des'''", "e'''", "g'''", "bes'''"),
-                ("dis,", "fis,", "a,", "c", "ees", "fis", "a", "c'", 
+                ("dis,", "fis,", "a,", "c", "ees", "fis", "a", "c'",
                  "ees'", "fis'", "a'", "c''", "ees''", "fis''", "a''",
                  "c'''", "ees'''", "fis'''", "a'''", "c''''"),
                 ("f,", "aes,", "b,", "d",
@@ -429,7 +432,7 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
                  "fis''", "a''", "c'''", "ees'''", "fis'''", "a'''", "c''''"),
                  )
         self.m_notenames_finnish = (
-                ("dis,", "fis,", "a,", "c", "ees", "fis", "a", "c'", 
+                ("dis,", "fis,", "a,", "c", "ees", "fis", "a", "c'",
                  "ees'", "fis'", "a'", "c''", "ees''", "fis''", "a''",
                  "c'''", "ees'''", "fis'''", "a'''", "c''''"),
                 ("d,", "f,", "aes,", "b,", "d",
@@ -474,7 +477,7 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
                                   rb+bw, -self.m_button_ydist),
                      fill_color='black', outline_color='black')
         for row in range(len(self.m_notenames)):
-            sx = (not row % 2) * self.m_button_xdist / 2 
+            sx = (not row % 2) * self.m_button_xdist / 2
             for notename in self.m_notenames[row]:
                 btn = kb.add('group')
                 btn.set_data('midi_int', mpd.notename_to_int(notename))
@@ -485,21 +488,22 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
                 else:
                     color = "white"
                     border = "black"
-                btn.add('ellipse', x1=-self.m_button_radius, 
+                btn.add('ellipse', x1=-self.m_button_radius,
                         x2=self.m_button_radius, y1=-self.m_button_radius,
                         y2=self.m_button_radius, fill_color=color,
                         outline_color=border)
                 if (notename[1:][:2] not in ("is", "es")) \
                    and (notename[0] in ("c", "f")):
                     btn.add('line', points=(-self.m_button_radius/2, -2,
-                         self.m_button_radius/2, -2), fill_color="gray")
+                         self.m_button_radius/2+1, -2), fill_color="gray")
                     btn.add('line', points=(-self.m_button_radius/2, 2,
-                         self.m_button_radius/2, 2), fill_color="gray")
+                         self.m_button_radius/2+1, 2), fill_color="gray")
                 btn.move(sx, row*self.m_button_ydist)
                 sx = sx + self.m_button_xdist
-        kb.move(-len(self.m_notenames[0])*self.m_button_xdist/2.7, 0)
-        self.set_usize((len(self.m_notenames[0])+1)*self.m_button_xdist+bw*2,
-                       self.m_button_ydist*7)
+        self.set_scroll_region(lb-bw, 0, rb+bw*2, bb)
+        # FIXME +10 just to get finish system not clip.
+        # Fix this for 2.0
+        self.set_usize(-lb+bw+rb+bw+10, self.m_button_ydist*2 + bb)
     def event_callback(self, group, event, midi_int):
         if event.type == GDK.BUTTON_PRESS:
             if self.m_clicked_tones:
@@ -535,7 +539,6 @@ class AccordionWidget(gnome.ui.GnomeCanvas):
     def know_directions(self):
         return 1
 
-import configureoutput
 if configureoutput.WITH_GNOME:
     inputwidget_names = [_("Buttons"), _("Piano"), _("Guitar"), _("Bass"),
                  _("5 string bass"), _("6 string bass"),
