@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,10 +20,9 @@ import re, string, types, os
 import const
 import random
 import gettext
-import mpd, cfg
+import mpd, cfg, utils
 from soundcard.rat import Rat
 
-from dataparser import i18nString, Dataparser
 import dataparser
 
 
@@ -40,14 +39,10 @@ predef = {'dictation': 'dictation',
                       'no': 0,
                       'tempo': (60, 4)}
 
-class LessonparserException:
-    pass
-
-
 class _Header:
     def __init__(self, headerdict):
         self.m_headerdict = headerdict
-        for s in ('description', 'labelformat', 'title'):
+        for s in ('description', 'labelformat', 'title', 'version'):
             if not self.m_headerdict.has_key(s):
                 self.m_headerdict[s] = ""
     def __getattr__(self, name):
@@ -59,17 +54,36 @@ class _Header:
 
 class LessonfileCommon:
     def _parse_file(self, filename):
-        parser = Dataparser(predef, ('tempo',))
+        parser = dataparser.Dataparser(predef, ('tempo',))
         parser.parse_file(filename)
         self._idx = 0
         self.m_transpose = mpd.MusicalPitch("c'")
-        H = map(lambda e: e[1], 
-                               filter(lambda e: e[0] == 'header',
-                                      parser.m_blocks))
+        H = filter(lambda e: e['blocktype'] == 'header', parser.m_blocks)
         self.header = _Header(H[0])
-        self.m_questions = map(lambda e: e[1], 
-                               filter(lambda e: e[0] == 'question',
-                                      parser.m_blocks[1:]))
+        self.m_questions = filter(lambda e: e['blocktype'] == 'question',
+                                  parser.m_blocks)
+        if utils.compare_version_strings(self.header.version, "1.1.3") == -1:
+            def convert(q):
+                for n in ('music', 'clue_music'):
+                    if not q.has_key(n):
+                        continue
+                    re_old_times = re.compile(r"\\time\s+(\d+)\s*/\s*(\d+);")
+                    r = re_old_times.search(q[n])
+                    while r:
+                        q[n] = q[n][:r.start()]+r"\time %s/%s" % (r.group(1), r.group(2))+q[n][r.end():]
+                        r = re_old_times.search(q[n])
+                    re_old_key = re.compile(r"\s*\\key\s+([a-z]+)\s*\\(major|minor);")
+                    r = re_old_key.search(q[n])
+                    while r:
+                        q[n] = q[n][:r.start()]+r"\key %s \%s" % (r.group(1), r.group(2))+q[n][r.end():]
+                        r = re_old_key.search(q[n])
+                    re_old_clef = re.compile(r"\s*\\clef\s+(\w*);")
+                    r = re_old_clef.search(q[n])
+                    while r:
+                        q[n] = q[n][:r.start()]+r" \clef %s" % r.group(1) + q[n][r.end():]
+                        r = re_old_clef.search(q[n])
+                return q
+            map(convert, self.m_questions)
     def select_random_question(self):
         """
         Select a question by random. Set the self.m_transpose variable if
@@ -78,8 +92,12 @@ class LessonfileCommon:
         old_music = self.get_music()
         while 1:
             self._idx = random.randint(0, len(self.m_questions) - 1)
-            if self.header.random_transpose:
+            if self.header.random_transpose == 1:
                 self.m_transpose = mpd.MusicalPitch().randomize("g", "fis'")
+            elif type(self.header.random_transpose) == type([]):
+                self.m_transpose = mpd.MusicalPitch().randomize(
+                  mpd.transpose_notename("c'", self.header.random_transpose[0]),
+                  mpd.transpose_notename("c'", self.header.random_transpose[1]))
             if old_music == self.get_music() \
                 and (len(self.m_questions) > 1 or self.header.random_transpose):
                 continue
@@ -130,7 +148,7 @@ class DictationLessonfile(LessonfileCommon):
     def select_next(self):
         if self._idx < len(self.m_questions) -1:
             self._idx = self._idx + 1
-        
+
 
 class SingChordLessonfile(LessonfileCommon):
     def __init__(self, filename):
@@ -151,9 +169,9 @@ class SingChordLessonfile(LessonfileCommon):
         if self.m_questions[self._idx].has_key('key'):
             k = self.m_questions[self._idx]['key']
         music = r"""
-                \staff{ \key %s;\stemUp <%s> }
+                \staff{ \key %s\stemUp <%s> }
                 \addvoice{ \stemDown <%s> }
-                \staff{ \key %s;\clef bass; \stemUp <%s>}
+                \staff{ \key %s\clef bass \stemUp <%s>}
                 \addvoice{ \stemDown <%s>}
                 """ % (k, v[0], v[1], k, v[2], v[3])
         if self.header.random_transpose:
@@ -242,7 +260,7 @@ class ChordLessonfile(LessonfileCommon):
         self.m_toptones = []
         for question in self.m_questions:
             self.m_chord_types[question['name']] = dataparser.get_translated_string(question, 'name')
-            
+
             # inversion
             if question.has_key('inversion') \
                     and question['inversion'] not in self.m_inversions:
@@ -278,17 +296,6 @@ class ChordLessonfile(LessonfileCommon):
     def get_chordtype(self):
         return self.m_questions[self._idx]['name']
 
-
-class LessonfileManagerParser(dataparser.Dataparser):
-    def end_block(self):
-        if self.m_blocks[-1][0] == 'header':
-            self._idx = len(self._data)
-            return
-        if self.m_context == self.m_globals:
-            raise "No block to close. Lineno:", self._lineno
-        self.m_context = self.m_globals
-
-
 class LessonFileManager:
     def __init__(self):
         self.parse()
@@ -308,14 +315,12 @@ class LessonFileManager:
                   or not os.path.isfile(self.get_complete_filename(collection, filename)):
                     continue
                 try:
-                    p = LessonfileManagerParser(predef)
-                    f = open(self.get_complete_filename(collection, filename), "r")
-                    p._parse(f.read())
-                    f.close()
+                    p = dataparser.Dataparser(predef)
+                    p.parse_file(self.get_complete_filename(collection, filename), 1)
                 except dataparser.DataparserException:
                     self.m_invalid_files.append(filename)
                     continue
-                c = p.m_blocks[0][1]['content']
+                c = p.m_blocks[0]['content']
                 if type(c) == types.StringType:
                     c = [c]
                 for u in c:
@@ -336,9 +341,7 @@ class LessonFileManager:
                     P = {const.USE_CHORD: 'chord',
                          const.USE_HARMONY: 'harmonic-progression-dictation',
                          const.USE_ID_BY_NAME: 'id-by-name',
-                         'id-by-name': 'id-by-name',
                          const.USE_DICTATION: 'dictation',
-                         'sing-chord': 'sing-chord',
                          const.USE_SING_CHORD: 'sing-chord'}[use]
                     self.m_htmldoc = self.m_htmldoc + \
                       "<a href=\"solfege:practise/%s/%s/%s\">%s</a> " % (P, collection, file, file)
