@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,9 +15,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# random has to be imported before gtk on win32
-import random
-import sys, time
+import sys
+
+if '--inithack' in sys.argv:
+    import src.inithack
+    del sys.argv[sys.argv.index('--inithack')]
+
+import src.rcfile
+src.rcfile.copy_rc12_file()
+
+import time, random
 from i18n import _
 import configureoutput
 
@@ -76,7 +83,11 @@ if '--gtk-help' in sys.argv:
 # silent, GNOME, be silent!
 sys.argv.append('--disable-sound')
 
+import locale
 import gtk
+if sys.platform == 'win32':
+    locale.setlocale(locale.LC_NUMERIC, "C")
+
 gtk.rc_parse("solfege.gtkrc")
 
 class SplashWin(gtk.GtkWindow):
@@ -126,6 +137,7 @@ from configwindow import ConfigWindow
 import mpd, mpd.musicdisplayer, gu, cfg
 import tracebackwindow
 
+
 # redirect error messages to a window that will popup if
 # something bad happens.
 
@@ -168,7 +180,7 @@ class MusicViewerWindow(gtk.GtkDialog):
         gtk.GtkDialog.__init__(self)
         self.m_app = app
         self.set_usize(400, 200)
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.vbox.pack_start(self.g_music_displayer)
         gu.bButton(self.action_area, _("Close"), self.m_app.close_musicviewer)
         self.connect('destroy', self.m_app.close_musicviewer)
@@ -215,10 +227,11 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         if not self.g_about_window:
             self.g_about_window = gnome.ui.GnomeAbout(
                     'GNU Solfege', configureoutput.VERSION_STRING,
-                    'Copyright (C) 2000-2001 Tom Cato Amundsen',
+                    'Copyright (C) 2000, 2001 Tom Cato Amundsen',
                     ['Tom Cato Amundsen',
                      'Oliver Vollmer %s' % _("(toolbar icons)"),
                      'Giovanni Chierico %s' % _("(some lessonfiles)"),
+                     'Joe Lee %s' % _("(sound code for the MS Windows port)"),
                      ],
                     #['see AUTHORS file or online documentation for details'],
                     _("GPL'ed eartraining.") + "\n"
@@ -245,8 +258,10 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         self.box_dict[exname].on_start_practise()
         self.m_viewer = exname
         if action in ['practise', 'config', 'statistics']:
-            self.box_dict[self.m_viewer].g_notebook.set_page(
-               ['practise', 'config', 'statistics'].index(action))
+            # We need this test because not all exercises use a notebook.
+            if self.box_dict[self.m_viewer].g_notebook:
+                self.box_dict[self.m_viewer].g_notebook.set_page(
+                   ['practise', 'config', 'statistics'].index(action))
         self.set_title("Solfege - " + self.box_dict[exname].get_pretty_name())
         self.m_history.add(href)
     def _show_docviewer(self):
@@ -306,7 +321,7 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         for e in const.exercises:
             file_menu.append(
              (APP_UI_ITEM, const.exercisedata[e][0], None,
-              lambda _o, self=self, e=e: self.m_app.handle_href("solfege:/"+e),
+              lambda _o, self=self, e=e: self.m_app.handle_href("solfege:practise/"+e),
               None, APP_PIXMAP_NONE, None,
               const.exercisedata[e][2], const.exercisedata[e][3]))
         file_menu = file_menu + [
@@ -363,6 +378,11 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
             UIINFO_ITEM_STOCK(_("Experiment"), None,
                               self.experiment, STOCK_MENU_EXEC),
                  ]
+        if configureoutput.ENABLE_TUNER:
+            development_menu = development_menu + [
+            (APP_UI_ITEM, _("Tuner"), None,
+             lambda _o, s=self: s.m_app.handle_href('solfege:/tuner'),
+             None, APP_PIXMAP_NONE, None, 0, 0)]
         self.m_menuinfo = menu = [
             UIINFO_SUBTREE(_("_File"), file_menu),
             UIINFO_SUBTREE(_("_Development"), development_menu),
@@ -386,12 +406,12 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         bg = self.get_style().bg[gtk.STATE_NORMAL]
         for i in const.exercises:
             n = string.replace(const.exercisedata[i][0], '_', '')
-            pix, mask = gtk.create_pixmap_from_xpm(self, None, 
+            pix, mask = gtk.create_pixmap_from_xpm(self, None,
                os.path.join('xpm', const.exercisedata[i][1]))
             self.g_toolbar.append_item(n, n, i, gtk.GtkPixmap(pix, mask),
-                    lambda id, self=self, i=i: self.m_app.handle_href("solfege:/"+i))
+                    lambda id, self=self, i=i: self.m_app.handle_href("solfege:practise/"+i))
         self.add_toolbar(self.g_toolbar, "main-toolbar",
-                         gnome.uiconsts.DOCK_ITEM_BEH_NORMAL, 
+                         gnome.uiconsts.DOCK_ITEM_BEH_NORMAL,
                          gnome.uiconsts.DOCK_TOP, 1, 1, 0)
         self.g_navbar = gtk.GtkToolbar(gtk.ORIENTATION_HORIZONTAL,
                                        gtk.TOOLBAR_ICONS)
@@ -407,14 +427,14 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         self.add_toolbar(self.g_navbar, 'backandforward',
                          gnome.uiconsts.DOCK_ITEM_BEH_NORMAL, 
                          gnome.uiconsts.DOCK_TOP, 1, 0, 0)
-    def close_musicviewer(self, widget=None):
-        self.g_musicviewer_window.destroy()
-        self.g_musicviewer_window = None
     def display_in_musicviewer(self, music):
         if not self.g_musicviewer_window:
             self.g_musicviewer_window = MusicViewerWindow(self)
             self.g_musicviewer_window.show()
         self.g_musicviewer_window.display_music(music)
+    def close_musicviewer(self, widget=None):
+        self.g_musicviewer_window.destroy()
+        self.g_musicviewer_window = None
 
 w = MainWin(args)
 w.show()
