@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,8 @@ RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
            "c12 c12 c12", "r12 c12 c12",
            "c12 r12 c12", "c12 c12 r12", "r12 r12 c12", "r12 c12 r12",
            )
- 
+
+
 class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
@@ -46,7 +47,7 @@ class Teacher(abstract.Teacher):
         if self.m_timeout_handle:
             gtk.timeout_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
-            
+
         if self.get_bool('config/picky_on_new_question') \
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
              return Teacher.ERR_PICKY
@@ -57,7 +58,7 @@ class Teacher(abstract.Teacher):
         v = []
         for x in range(len(RHYTHMS)):
             if self.get_bool("rhythm_element_%i" % x):
-                if not (RHYTHMS[x][0] == "r" 
+                if not (RHYTHMS[x][0] == "r"
                         and self.get_bool("not_start_with_rest")):
                     norest_v.append(x)
                 v.append(x)
@@ -79,7 +80,7 @@ class Teacher(abstract.Teacher):
         if self.q_status == const.QSTATUS_NO:
             return
         score = mpd.parser.parse_to_score_object(self.get_music_string())
-        track = score.get_midi_events_with_channel(9)[0]
+        track = score.get_midi_events_with_channel(9, cfg.get_int('config/preferred_instrument_velocity'))[0]
         track.prepend_bpm(self.get_int("bpm"))
         track.replace_note(mpd.notename_to_int("c"),
                            self.get_int("rhythm_perc"), 9)
@@ -102,7 +103,7 @@ class Teacher(abstract.Teacher):
             self.m_app.play_sad_sound()
 
 def load_xpm(parent, filename):
-    pix, mask = gtk.create_pixmap_from_xpm(parent, None, 
+    pix, mask = gtk.create_pixmap_from_xpm(parent, None,
                                            os.path.join("xpm", filename))
     return gtk.GtkPixmap(pix, mask)
 
@@ -225,6 +226,7 @@ class RhythmViewer(gtk.GtkFrame):
         self.__timeout = None
         self.clear()
 
+
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
@@ -290,7 +292,7 @@ class Gui(abstract.Gui):
         table.attach(label, 0, 1, 0, 1, xpadding=gnome.uiconsts.PAD_SMALL,
                       xoptions=gtk.FILL)
         table.attach(gu.nSpinButton(self.m_exname, "num_beats",
-                     gtk.GtkAdjustment(4, 1, 100, 1, 10)), 
+                     gtk.GtkAdjustment(4, 1, 100, 1, 10)),
                      1, 2, 0, 1, xoptions=gtk.FILL)
         self.g_rhythm_perc_combo = combo = gu.PercussionNameCombo(self.m_exname, "rhythm_perc", "Side Stick")
         table.attach(combo, 2, 3, 0, 1, xoptions=gtk.FILL)
@@ -299,7 +301,7 @@ class Gui(abstract.Gui):
         table.attach(label, 0, 1, 1, 2, xpadding=gnome.uiconsts.PAD_SMALL,
                      xoptions=gtk.FILL)
         table.attach(gu.nSpinButton(self.m_exname, "count_in",
-                     gtk.GtkAdjustment(2, 0, 10, 1, 10)), 
+                     gtk.GtkAdjustment(2, 0, 10, 1, 10)),
                      1, 2, 1, 2, xoptions=gtk.FILL)
         combo = gu.PercussionNameCombo(self.m_exname, "countin_perc",
                                        "Claves")
@@ -310,13 +312,13 @@ class Gui(abstract.Gui):
         #------
         hbox = gu.bHBox(self.config_box, gtk.FALSE)
         hbox.set_spacing(gnome.uiconsts.PAD_SMALL)
-        hbox.pack_start(gu.nCheckButton(self.m_exname, 
-                 "not_start_with_rest", 
+        hbox.pack_start(gu.nCheckButton(self.m_exname,
+                 "not_start_with_rest",
                  _("Don't start the question with a rest")), gtk.FALSE)
         sep = gtk.GtkVSeparator()
         hbox.pack_start(sep, gtk.FALSE)
         hbox.pack_start(gtk.GtkLabel(_("Beats per minute:")), gtk.FALSE)
-        spin = gu.nSpinButton(self.m_exname, 'bpm', 
+        spin = gu.nSpinButton(self.m_exname, 'bpm',
                  gtk.GtkAdjustment(60, 20, 240, 1, 10))
         hbox.pack_start(spin, gtk.FALSE)
         self._add_auto_new_question_gui(self.config_box)
