@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,10 +16,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
-import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract, random
-import lessonfile, statistics, string
+import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
+import lessonfile, string
 from i18n import _
 import widgets
+import utils
 
 class Teacher(abstract.LessonbasedTeacher):
     def __init__(self, exname, app):
@@ -70,10 +71,10 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.set_usize(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
-        
+
         self.g_new = gu.bButton(self.action_area, _("New"), self.new_question)
         gu.bButton(self.action_area, _("440hz"), lambda f, s=self: s.m_t.play_440hz())
         self.g_play_answer = gu.bButton(self.action_area, _("Play answer"), lambda f, s=self: s.m_t.play_answer_arpeggio())
