@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,11 +15,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import time, os, pickle, string
+import time, os, pickle
 import utils
 import configureoutput
 
-STATISTICS_SAVE_DIR = os.path.join(os.path.expanduser('~'), 
+STATISTICS_SAVE_DIR = os.path.join(os.path.expanduser('~'),
        '.solfege%s.%s' % (configureoutput.MAJOR_VERSION, configureoutput.MINOR_VERSION))
 if not os.path.exists(STATISTICS_SAVE_DIR):
     os.mkdir(STATISTICS_SAVE_DIR)
@@ -145,7 +145,8 @@ class AbstractStatistics:
         return k
     def get_label_style(self):
         return 'normal'
-
+    def reset_session(self):
+        self.m_session_stat = {}
 
 
 class Statistics(AbstractStatistics):
@@ -157,7 +158,8 @@ class Statistics(AbstractStatistics):
             f = open(os.path.join(self.m_savepath, str(int(time.time()))), 'w')
             pickle.dump(self.m_session_stat, f)
             f.close()
-        
+
+
 class LessonStatistics(AbstractStatistics):
     def __init__(self, teacher):
         AbstractStatistics.__init__(self, teacher)
@@ -183,7 +185,7 @@ class LessonStatistics(AbstractStatistics):
         # if the lessonfile has changed, we have to
         # delete all statistics just to be save.
         if self.get_hash_of_statistics() != self.get_hash_of_lessonfile():
-            p = os.path.join(self.m_savepath, 
+            p = os.path.join(self.m_savepath,
                              self.m_cur_collection,
                              self.m_cur_file)
             if os.path.isfile("%s_hash" % p):
@@ -197,7 +199,7 @@ class LessonStatistics(AbstractStatistics):
         if self.m_session_stat == {}:
             return
         #save the hashvalue for the lessonfile this statistics was made with
-        f = open(os.path.join(self.m_savepath, 
+        f = open(os.path.join(self.m_savepath,
                               self.m_cur_collection,
                               '%s_hash' % self.m_cur_file), 'w')
         f.write(str(self.get_hash_of_lessonfile()))
@@ -212,7 +214,7 @@ class LessonStatistics(AbstractStatistics):
         dir = os.path.join(self.m_savepath, self.m_cur_collection)
         if not os.path.exists(dir):
             os.mkdir(dir)
-        
+
         dir = os.path.join(dir, self.m_cur_file)
         if not os.path.exists(dir):
             os.mkdir(dir)
@@ -237,6 +239,7 @@ class LessonStatistics(AbstractStatistics):
             self.m_t.get_string('lessoncollections/%s' % self.m_cur_collection),
             self.m_cur_file))).read())
 
+
 class IntervallStatistics(Statistics):
     def key_to_pretty_name(self, key):
         return utils.int_to_intervallname(key, 1, 1)
