@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,10 +15,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import random
+import gtk
+
 import gu, const, soundcard, mpd, mpd.musicdisplayer
 from i18n import _
-import abstract, gtk
-import random
+import abstract, utils
 
 class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
@@ -50,7 +52,7 @@ class Teacher(abstract.Teacher):
         for n in self.m_question:
             s = s + " " + n
         s = s + "}"
-        track = mpd.music_to_track(s)
+        track = mpd.music_to_track(s, self.get_int('config/preferred_instrument_velocity'))
         track.prepend_patch(0, self.get_int('config/preferred_instrument'))
         soundcard.synth.play_track(track)
 
@@ -63,11 +65,11 @@ class Gui(abstract.Gui):
                                'play_first_note_ak': self.m_t.play_question,
                                'play_last_note_ak': self.m_t.play_last_note,
                                'play_all_ak': self.m_t.play_all_notes}
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.clear()
         self.g_music_displayer.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
         self.practise_box.pack_start(self.g_music_displayer)
-        
+
         gu.bButton(self.action_area, _("New"), self.new_question)
         self.g_play_first_note = gu.bButton(self.action_area, _("Play first note"), lambda f, s=self: s.m_t.play_question())
         self.g_play_first_note.set_sensitive(gtk.FALSE)
