@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,14 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import GDK, string, re
+import GDK, string, re, math
 import mpd
 import const
 import random
 import types
 from i18n import _
 import sys
-import gettext
+import soundcard, cfg
+
+def play_tone(midi_int):
+    soundcard.play_note(cfg.get_int('config/preferred_instrument'),
+                        4, 0, midi_int,
+                        cfg.get_int('config/preferred_instrument_velocity'))
 
 def int_to_intervallname(i, shortname=None, updown=None):
     if shortname:
@@ -123,7 +128,7 @@ def adjust_low_high_to_irange(lowest, highest, irange):
         H = H + (r - (H - L)) / 2
         L = L - (r - (H - L))
     return L, H
-  
+
 
 def parse_url(s):
     # protocol, action, fn, collection, lessonfile, config
@@ -157,7 +162,7 @@ def get_modifier(s):
     for mod, mask in m:
         if s[:len(mod)] == mod:
             return mask, s[len(mod):]
-    return None, s 
+    return None, s
 
 def parse_key_string(string):
     if not string:
@@ -172,6 +177,52 @@ def parse_key_string(string):
     else:
         return mod, GDK.__dict__[s]
 
+def freq_to_notename_cent(freq):
+    e = 440.0
+    if e > freq:
+        while e > freq:
+            e = e / 2
+    else:
+        while e < freq/2:
+            e = e * 2
+    d = freq / e
+    v = 12 * math.log(d) / math.log(2)
+    i = int(v)
+    cent = (v-i) * 100
+    n = ('a', 'ais', 'b', 'c', 'cis', 'd', 'dis', 'e', 'f', 'fis', 'g', 'gis')
+    if cent > 50:
+        return n[(i+1) % 12], cent-100
+    return n[int(v)], (v-int(v)) * 100
+
 def exercise_name_to_module_name(name):
     # it is just plain luck that this works...
     return string.replace(name, '-', '')
+
+def compare_version_strings(A, B):
+    """
+    Works with version strings like 1, 1.0, 1.1.3, 1.4.3.2
+    Returns:
+        -1 if A < B
+         0 if A == B
+         1 if A > B
+    """
+    if A == B == "":
+        return 0
+    elif A == "":
+        return -1
+    elif B == "":
+        return 1
+    av = map(lambda s: int(s), string.split(A, "."))
+    bv = map(lambda s: int(s), string.split(B, "."))
+    x = 0
+    while len(av) > x < len(bv):
+        if av[x] > bv[x]:
+            return 1
+        elif av[x] < bv[x]:
+            return -1
+        x = x + 1
+    if len(av) > len(bv):
+        return 1
+    elif len(av) < len(bv):
+        return -1
+    return 0
