@@ -10,6 +10,7 @@ gnome.config.push_prefix("Solfege/")
 import mpd, mpd.musicdisplayer, soundcard
 import gtk
 from src import gu
+import src.utils
 
 class DisplaytestWindow(gtk.GtkWindow):
     def on_quit(self, w):
@@ -28,7 +29,7 @@ class DisplaytestWindow(gtk.GtkWindow):
             s = r"\staff{c' d' e'}"
         self.g_text.insert_defaults(s)
         vbox.pack_start(self.g_text)
-        self.g_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_displayer = mpd.musicdisplayer.MusicDisplayer(src.utils.play_tone)
         self.g_displayer.set_usize(200, 200)
         self.g_displayer.show()
         self.vbox.pack_start(self.g_displayer)
@@ -57,13 +58,14 @@ class DisplaytestWindow(gtk.GtkWindow):
     def on_play(self, _o):
         t = self.g_text.get_chars(0, -1)
         gnome.config.set_string('config/score_displayer', t)
-        mpd.play_music(t, (120, 4), 40)
+        mpd.play_music(t, (120, 4), 0)
     def on_play_first(self, _o):
         t = self.g_text.get_chars(0, -1)
         tr = mpd.music_to_track(t, soundcard.rat.Rat(0, 1), soundcard.rat.Rat(1, 8))
         soundcard.synth.play_track(tr)
 
-#soundcard.initialise_external_midiplayer("drvmidi -i d %s")
+
+#soundcard.initialise_devicefile("/dev/sequencer", 0)
 soundcard.initialise_devicefile("/dev/music", 0)
 #soundcard.initialise_using_fake_synth()
 
